@@ -19,6 +19,7 @@ import json
 import jinja2
 import six
 import six.moves
+import webob.request
 import yaml
 
 from gnocchi.tests import test_rest
@@ -31,7 +32,7 @@ _RUN = False
 
 def _setup_test_app():
     t = test_rest.RestTest()
-    t.auth = True
+    t.auth_mode = "basic"
     t.setUpClass()
     t.setUp()
     return t.app
@@ -116,6 +117,17 @@ def setup(app):
         fake_file.write(template.render(scenarios=scenarios).encode('utf-8'))
         fake_file.seek(0)
         request = webapp.RequestClass.from_file(fake_file)
+
+        # TODO(jd) Fix this lame bug in webob < 1.7
+        if (hasattr(webob.request, "http_method_probably_has_body")
+           and request.method == "DELETE"):
+            # Webob has a bug it does not read the body for DELETE, l4m3r
+            clen = request.content_length
+            if clen is None:
+                request.body = fake_file.read()
+            else:
+                request.body = fake_file.read(clen)
+
         app.info("Doing request %s: %s" % (entry['name'],
                                            six.text_type(request)))
         with webapp.use_admin_user():
